CHUNK_SIZE = 32768

CONFIGURATION = {
    "digit_config": {
        "0": {
            "fontscale": 30,
            "size": [
                17,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                16,
                26
            ]
        },
        "1": {
            "fontscale": 30,
            "size": [
                11,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                8,
                26
            ]
        },
        "2": {
            "fontscale": 30,
            "size": [
                16,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                15,
                26
            ]
        },
        "3": {
            "fontscale": 30,
            "size": [
                16,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                15,
                26
            ]
        },
        "4": {
            "fontscale": 30,
            "size": [
                16,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                15,
                26
            ]
        },
        "5": {
            "fontscale": 30,
            "size": [
                16,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                15,
                26
            ]
        },
        "6": {
            "fontscale": 30,
            "size": [
                16,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                15,
                26
            ]
        },
        "7": {
            "fontscale": 30,
            "size": [
                16,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                15,
                26
            ]
        },
        "8": {
            "fontscale": 30,
            "size": [
                17,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                14,
                26
            ]
        },
        "9": {
            "fontscale": 30,
            "size": [
                17,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                16,
                26
            ]
        },
        " ": {
            "fontscale": 30,
            "size": [
                10,
                30
            ],
            "start_point": [
                0,
                0
            ],
            "bbox": [
                0,
                4,
                9,
                26
            ]
        },
        "default": {
            "fontscale": 30,
            "size": [
                20,
                30
            ],
            "start_point": [
                3,
                0
            ],
            "bbox": [
                1,
                1,
                19,
                29
            ]
        }
    },
    "common_configs": {
        "background_color": (
            255,
            255,
            255
        ),
        "digit_color": (
            0,
            0,
            0
        ),
        "bbox_color": [
            255,
            82,
            82
        ],
        "bbox_width": 1
    }
}
